@@ -7,18 +7,18 @@ from typing import Union
 
 from rockset.api_client import ApiClient
 from rockset.apis import (
-    AliasesApi,
-    APIKeysApi,
-    CollectionsApi,
-    DocumentsApi,
-    IntegrationsApi,
-    OrganizationsApi,
-    QueriesApi,
-    QueryLambdasApi,
-    UsersApi,
-    ViewsApi,
-    VirtualInstancesApi,
-    WorkspacesApi,
+    Aliases,
+    APIKeys,
+    Collections,
+    Documents,
+    Integrations,
+    Organizations,
+    Queries,
+    QueryLambdas,
+    Users,
+    Views,
+    VirtualInstances,
+    Workspaces,
 )
 from rockset.configuration import Configuration
 from rockset.exceptions import ApiTypeError, ApiValueError, InitializationException
@@ -85,51 +85,51 @@ class ApiMetaclass(type):
         return child
 
 
-class AliasesApiWrapper(AliasesApi, metaclass=ApiMetaclass):
+class AliasesApiWrapper(Aliases, metaclass=ApiMetaclass):
     pass
 
 
-class APIKeysApiWrapper(APIKeysApi, metaclass=ApiMetaclass):
+class APIKeysApiWrapper(APIKeys, metaclass=ApiMetaclass):
     pass
 
 
-class CollectionsApiWrapper(CollectionsApi, metaclass=ApiMetaclass):
+class CollectionsApiWrapper(Collections, metaclass=ApiMetaclass):
     pass
 
 
-class DocumentsApiWrapper(DocumentsApi, metaclass=ApiMetaclass):
+class DocumentsApiWrapper(Documents, metaclass=ApiMetaclass):
     pass
 
 
-class IntegrationsApiWrapper(IntegrationsApi, metaclass=ApiMetaclass):
+class IntegrationsApiWrapper(Integrations, metaclass=ApiMetaclass):
     pass
 
 
-class OrganizationsApiWrapper(OrganizationsApi, metaclass=ApiMetaclass):
+class OrganizationsApiWrapper(Organizations, metaclass=ApiMetaclass):
     pass
 
 
-class QueriesApiWrapper(QueriesApi, metaclass=ApiMetaclass):
+class QueriesApiWrapper(Queries, metaclass=ApiMetaclass):
     pass
 
 
-class QueryLambdasApiWrapper(QueryLambdasApi, metaclass=ApiMetaclass):
+class QueryLambdasApiWrapper(QueryLambdas, metaclass=ApiMetaclass):
     pass
 
 
-class UsersApiWrapper(UsersApi, metaclass=ApiMetaclass):
+class UsersApiWrapper(Users, metaclass=ApiMetaclass):
     pass
 
 
-class ViewsApiWrapper(ViewsApi, metaclass=ApiMetaclass):
+class ViewsApiWrapper(Views, metaclass=ApiMetaclass):
     pass
 
 
-class VirtualInstancesApiWrapper(VirtualInstancesApi, metaclass=ApiMetaclass):
+class VirtualInstancesApiWrapper(VirtualInstances, metaclass=ApiMetaclass):
     pass
 
 
-class WorkspacesApiWrapper(WorkspacesApi, metaclass=ApiMetaclass):
+class WorkspacesApiWrapper(Workspaces, metaclass=ApiMetaclass):
     pass
 
 
@@ -155,7 +155,7 @@ class RocksetClient:
         )
         result = await future
     """
-    def __init__(self, host: Union[str, Regions, DevRegions] = None, api_key: str = None, max_workers: int=4, config: Configuration=None):
+    def __init__(self, host: Union[str, Regions, DevRegions] = None, api_key: str = None, max_workers: int = 4, config: Configuration = None):
         """
         Keyword Args:
             host (str, Regions, DevRegions): Base url of the Rockset apiserver that should be used.
@@ -170,9 +170,12 @@ class RocksetClient:
             max_workers (int): The max number of workers that the ThreadPoolExecutor
                 should use when making asynchronous requests. [optional]
         """
+        if not host and config and config.host:
+            host = config.host
+
         if isinstance(host, Enum):
             host = host.value
-        else:
+        elif host:
             if host.startswith("http://"):
                 host = f"https://{host[7:]}"
             elif not host.startswith("https://"):
@@ -181,26 +184,28 @@ class RocksetClient:
             if host.endswith("/"):
                 host = host[:-1]
 
-        if not re.match(APISERVER_PATTERN, host):
-            raise InitializationException("The provided host was invalid and could not be parsed into a valid host.")
+            if not re.match(APISERVER_PATTERN, host):
+                raise InitializationException("The provided host was invalid and could not be parsed into a valid host.")
 
         if not config:
             config = Configuration(host=host, api_key=api_key)
+        else:
+            config.host = host
 
         if not config.api_key:
             raise InitializationException("An api key must be provided as a parameter to the RocksetClient or the Configuration object.")
 
         self.api_client = ApiClient(config, max_workers=max_workers)
 
-        self.AliasesApi = AliasesApiWrapper(self.api_client)
-        self.APIKeysApi = APIKeysApiWrapper(self.api_client)
-        self.CollectionsApi = CollectionsApiWrapper(self.api_client)
-        self.DocumentsApi = DocumentsApiWrapper(self.api_client)
-        self.IntegrationsApi = IntegrationsApiWrapper(self.api_client)
-        self.OrganizationsApi = OrganizationsApiWrapper(self.api_client)
-        self.QueriesApi = QueriesApiWrapper(self.api_client)
-        self.QueryLambdasApi = QueryLambdasApiWrapper(self.api_client)
-        self.UsersApi = UsersApiWrapper(self.api_client)
-        self.ViewsApi = ViewsApiWrapper(self.api_client)
-        self.VirtualInstancesApi = VirtualInstancesApiWrapper(self.api_client)
-        self.WorkspacesApi = WorkspacesApiWrapper(self.api_client)
+        self.Aliases = AliasesApiWrapper(self.api_client)
+        self.APIKeys = APIKeysApiWrapper(self.api_client)
+        self.Collections = CollectionsApiWrapper(self.api_client)
+        self.Documents = DocumentsApiWrapper(self.api_client)
+        self.Integrations = IntegrationsApiWrapper(self.api_client)
+        self.Organizations = OrganizationsApiWrapper(self.api_client)
+        self.Queries = QueriesApiWrapper(self.api_client)
+        self.QueryLambdas = QueryLambdasApiWrapper(self.api_client)
+        self.Users = UsersApiWrapper(self.api_client)
+        self.Views = ViewsApiWrapper(self.api_client)
+        self.VirtualInstances = VirtualInstancesApiWrapper(self.api_client)
+        self.Workspaces = WorkspacesApiWrapper(self.api_client)
